@@ -1,7 +1,5 @@
 # -*- coding: GBK -*-
 
-# next update: only keep product name
-
 import sys
 import os
 
@@ -20,8 +18,10 @@ from .regex_dictionary import get_section_regex
 
 class Contract:
     def __init__(self, path):
+        print(path)
+        self.exp = '(̩)|()(?!)|()(?!Ͷ)|()|(㷢)|(ͨ)|()|()|(ƽ)|()|(ҵ)|()|()(?:)()|(Ͷ)'
         self.path = path
-        self.product_name = regex.search('.+?', path).group()
+        self.product_name = regex.search('(|).+?', path).group()
         self.document = docx2python(path)
         self.full_text = ''
         for table in self.document.body:
@@ -29,7 +29,10 @@ class Contract:
                 for cell in row:
                     for para in cell:
                         self.full_text += para
-        self.tg = regex.search('̩||||㷢|ͨ|||ƽ|', path).group()
+        try:
+            self.tg = ''.join(filter(None,regex.search(self.exp, path).groups()))
+        except:
+            self.tg = ''
 
     def get_front_page(self):
         firstpages = {"":25,"ƽ":25,"":28,"ͨ":18,"":22,"":19,"㷢":0,"":25,"":28,"̩":23}
@@ -50,10 +53,10 @@ class Contract:
         chapter_regex = get_chapter_regex(self.tg, beg_chapter_name, end_chapter_name)
         try:
             self.chapter = regex.search(chapter_regex, self.full_text).group()
+            return self.chapter
         except:
             return 'No Regex Matches'
-        finally:
-            return self.chapter
+            
 
     def get_section_of_chapter(self, chapter, section):
         chapter = self.get_chapter(chapter)
@@ -64,15 +67,15 @@ class Contract:
             self.section = regex.search(section_regex, chapter).group()
             if self.section[0] == '':
                 self.section = self.section.replace('','')
+            return self.section
         except:
             return 'No Regex Matches'
-        finally:
-            return self.section
 
     # def to_pdf(): #under construnction, same as Contracts method, but only exports pdf of one contract document
 
 class Contracts:
     def __init__(self, folder_path):
+        self.exp = '(̩)|()(?!)||()(?!Ͷ)|()|(㷢)|(ͨ)|()|()|(ƽ)|()|(ҵ)|()|()(?:)()|(Ͷ)'
         self.folder_path = folder_path
         self.all_files = []
         self.tg = []
@@ -81,10 +84,10 @@ class Contracts:
                 path = os.path.join(root, name)
                 if 'output' not in path and 'docx' in path and 'Э' not in path:
                     try:
-                        self.tg.append(regex.search('̩||||㷢|ͨ|||ƽ|', path).group())
+                        self.tg.append(''.join(filter(None,regex.search(self.exp, path).groups())))
                         self.all_files.append(path)
                     except:
-                        print('Ŀǰֻ֧֣̩||||㷢|ͨ|||ƽ|йܵĲƷᱻԡ')
+                        print('Ŀǰֻ֧֣̩||ŽͶ||㷢|ͨ|||ƽ||ҵ||ͶйܵĲƷᱻԡ')
 
     def get_chapters(self, chapter_names):
         out = {}
