@@ -7,15 +7,17 @@ from re import S
 #         '':'߽ Ͷ.+(?=ڰ˽)','':'(?<=)ʮһ˽ļͶ.+(?<!)(?=ʮ)','̩':'ʮһ˽ļͶ[\S\s\n]+(?<!)(?=ʮ)','㷢':'ʮһ Ͷ.+(?<!)(?=ʮ)'}
 
 def get_chapter_regex(tg, beg_chapter_name, end_chapter_name):
-        if tg=='̩' or tg=='' or tg=='' or tg=='' or tg=='' or tg=='ƽ' or tg=='' or tg=='㷢': #done
+        if tg=='̩' or tg=='' or tg=='' or tg=='' or tg=='' or tg=='ƽ' or tg=='' or tg=='㷢' or tg=='Ͷ' or tg=='': #done
                 return r'(?<='+beg_chapter_name+r'[\S\s\n\t]+)'+beg_chapter_name+r'[\S\s\n\t]{10,}?(?='+end_chapter_name+')'
         if tg=='': #done
                 return r'(?<=--	'+beg_chapter_name+')'+r'[\S\s\n\t]{10,}?(?=--	'+end_chapter_name+')'
         if tg=='ͨ': #done
                 return r'(?<=--	'+beg_chapter_name+'--)'+r'[\S\s\n\t]{10,}?(?=--	'+end_chapter_name+')'
+        if tg=='ҵ': #done
+                return r'(?<=--(\t|	)'+beg_chapter_name+'--)'+r'[\S\s\n\t]{10,}?(?=--(\t|	)'+end_chapter_name+')'
 
 def get_section_regex(tg, beg_section_name, end_section_name):
-        if tg=='̩' or tg=='' or tg=='' or tg=='ƽ' or tg=='': #done
+        if tg=='̩' or tg=='' or tg=='' or tg=='ƽ' or tg=='' or tg=='Ͷ' or tg=='': #done
                 return r'(?<='+beg_section_name+r')[\S\s\t\n]+?(?=[\S\s\t\n]{,5}'+end_section_name+')'
         if tg=='': #done
                 return r'(?<=[\S]{1,2}'+beg_section_name+r')[\S\s\t\n]+?(?=[\S]{1,2}'+end_section_name+')'
@@ -23,6 +25,8 @@ def get_section_regex(tg, beg_section_name, end_section_name):
                 return r'(?<=--	'+beg_section_name+r')[\S\s\n\t]+?(?=--	'+end_section_name+')'
         if tg=='ͨ': #done
                 return r'(?<=--		'+beg_section_name+r')[\S\s\n\t]+?(?=--		'+end_section_name+')'
+        if tg=='ҵ': #done
+                return r'(?<=--(\t|	)'+beg_section_name+r')[\S\s\n\t]+?(?=--(\t|	)'+end_section_name+')'
 
 def get_section_beg_end(tg, req_section):
         sections_dict = {'̩':['ͶĿ','ͶʷΧ','Ͷʲ','ҵȽϻ׼','Ͷ','ͶʽֹΪ'],
@@ -34,7 +38,10 @@ def get_section_beg_end(tg, req_section):
                          '㷢':['Ʋı봦','Ʋ˻Ŀ͹', 'ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׼ͻμʽ','','Ԥֹ','ҵȽϻ׼','йͶʼලԼ'],
                          'ͨ':['Ͷʾ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׵μʽ','','ҵȽϻ׼','ȯҵ֤ȯҵ','Ԥֹ'],
                          'ƽ':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','/','ͶʽֹΪ','Ԥֹտ','ҵȽϻ׼У','','Ͷߵı'],
-                         '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','ҵȽϻ׼У','סܴڵͻμʽ','ȯͶҵУ','Ԥ/ֹ','Ͷʾ','Ͷߵı','У']}
+                         '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','ҵȽϻ׼У','סܴڵͻμʽ','ȯͶҵУ','Ԥ/ֹ','Ͷʾ','Ͷߵı','У'],
+                         'ҵ':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','Ͷ˽ļ˹˽ļݶ˵','ߣȯ֤ȯҵ','','ȫݶڴȨͬ','','Ԥֹ','Ͷʾָ'],
+                         '':['˿ɸ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','','','Ԥֹ','ҵȽϻ׼У','ýṹŵ',''],
+                         'Ͷ':['Ͷʾ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','','׼ͻμʽ','','Ԥֹ','ҵȽϻ׼','йͶʼලԼ']}
         return [(section, sections_dict[tg][idx+1]) for idx, section in zip(range(len(sections_dict[tg])), sections_dict[tg]) if req_section in section]
 
 def get_chapter_beg_end(tg, req_chapter):
@@ -331,6 +338,92 @@ def get_chapter_beg_end(tg, req_chapter):
                                 'ʮΥԼ',\
                                 'ʮߡúĴ',\
                                 'ʮˡ֪ͨʹ',\
-                                'ʮš']}
+                                'ʮš'],
 
+                        'ҵ':['սʾ',\
+                                'ǰ',\
+                                '',\
+                                'ŵ',\
+                                '˽ļĻ',\
+                                '˽ļļ',\
+                                '˽ļĳ뱸',\
+                                '˽ļ깺ת',\
+                                '˼Ȩ',\
+                                '˽ļݶ˴ἰճ',\
+                                '˽ļݶĵǼ',\
+                                '˽ļͶ',\
+                                '˽ļĲƲ',\
+                                '׼㽻հ',\
+                                'ԽȨ',\
+                                '˽ļƲĹֵͻƺ',\
+                                '˽ļķ˰',\
+                                '˽ļĲƲ',\
+                                'Ϣ¶뱨',\
+                                'սʾ',\
+                                '˽ļݶĶᡢⶳ',\
+                                'ͬЧֹ',\
+                                '˽ļ',\
+                                'ΥԼ',\
+                                'úĴ',\
+                                ''],
+
+                        'Ͷ':['Ҫʾ?',\
+                                'ŻƱ8˽ļ֤ȯͶʻսʾ?',\
+                                'ϸͶ߳ŵ?',\
+                                'Ͷ߸֪?',\
+                                'һǰ?',\
+                                '?',\
+                                'ŵ?',\
+                                'ġ˽ļĻ?',\
+                                '塢˽ļĽṹ?',\
+                                '˽ļļ?',\
+                                'ߡ˽ļĳ뱸?',\
+                                'ˡ˽ļ깺غת?',\
+                                'š˵Ȩ?',\
+                                'ʮݶ˴ἰճ?',\
+                                'ʮһ˽ļݶĵǼ?',\
+                                'ʮ˽ļͶ?',\
+                                'ʮ˽ļĲƲ?',\
+                                'ʮġʽ㽻հ?',\
+                                'ʮ塢Ͷָķ͡ȷϺִ?',\
+                                'ʮ˽ļʲĹֵͻƺ?',\
+                                'ʮߡ˽ļķ˰?',\
+                                'ʮˡ˽ļ?',\
+                                'ʮšϢ¶뱨?',\
+                                'ʮսʾ?',\
+                                'ʮһ˽ļͬЧֹ?',\
+                                'ʮ˽ļ?',\
+                                'ʮΥԼ?',\
+                                'ʮġĴ?',\
+                                'ʮ塢ά?',\
+                                'ʮ?'],
+                        
+                        '':['һǰ',\
+                                '',\
+                                'ŵ',\
+                                'ġ˽ļĻ',\
+                                '塢˽ļļ',\
+                                '˽ļĳ뱸',\
+                                'ߡ˽ļݶ깺ת',\
+                                'ˡ˼Ȩ',\
+                                'šݶ˴ἰճ',\
+                                'ʮ˽ļݶĵǼ',\
+                                'ʮһ˽ļͶ',\
+                                'ʮ˽ļĲƲ',\
+                                'ʮָķ͡ȷִ',\
+                                'ʮġ׼㽻հ',\
+                                'ʮ塢˽ļƲĹֵƺ',\
+                                'ʮ˽ļķ˰',\
+                                'ʮߡ˽ļ',\
+                                'ʮˡ˽ļϢ¶뱨',\
+                                'ʮšսʾ',\
+                                'ʮݶķǽ׹ᡢⶳѺ',\
+                                'ʮһͬĳЧǩ',\
+                                'ʮͬЧ',\
+                                'ʮͬıֹ',\
+                                'ʮġ˽ļ',\
+                                'ʮ塢ΥԼ',\
+                                'ʮ֪ͨʹ',\
+                                'ʮߡúĴ',\
+                                'ʮˡ']}
         return [(chapter, chapters_dict[tg][idx+1]) for idx, chapter in zip(range(len(chapters_dict[tg])), chapters_dict[tg]) if req_chapter in chapter]
\ No newline at end of file
